@@ -1,6 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * Main loader script
  *
  * @package PhpMyAdmin
  */
@@ -74,7 +75,7 @@ if (! empty($message)) {
     unset($message);
 }
 
-$common_url_query =  PMA_generate_common_url('', '');
+$common_url_query =  PMA_URL_getCommon('', '');
 
 // when $server > 0, a server has been chosen so we can display
 // all MySQL-related information
@@ -92,12 +93,12 @@ if ($server > 0) {
         }
     }
     if ($GLOBALS['cfg']['ShowServerInfo'] || empty($cfg['Server']['verbose'])) {
-        $server_info .= PMA_DBI_get_host_info();
+        $server_info .= $GLOBALS['dbi']->getHostInfo();
     }
     if (! empty($cfg['Server']['verbose']) && $GLOBALS['cfg']['ShowServerInfo']) {
         $server_info .= ')';
     }
-    $mysql_cur_user_and_host = PMA_DBI_fetch_value('SELECT USER();');
+    $mysql_cur_user_and_host = $GLOBALS['dbi']->fetchValue('SELECT USER();');
 
     // should we add the port info here?
     $short_server_info = (!empty($GLOBALS['cfg']['Server']['verbose'])
@@ -109,6 +110,21 @@ echo '<div id="maincontainer">' . "\n";
 echo '<div id="main_pane_left">';
 if ($server > 0 || count($cfg['Servers']) > 1
 ) {
+    if ($cfg['DBG']['demo']) {
+        echo '<div class="group">';
+        echo '<h2>' . __('phpMyAdmin Demo Server') . '</h2>';
+        echo '<p style="margin: 0.5em 1em 0.5em 1em">';
+        printf(
+            __(
+                'You are using the demo server. You can do anything here, but '
+                . 'please do not change root, debian-sys-maint and pma users. '
+                . 'More information is available at %s.'
+            ),
+            '<a href="http://demo.phpmyadmin.net/">demo.phpmyadmin.net</a>'
+        );
+        echo '</p>';
+        echo '</div>';
+    }
     echo '<div class="group">';
     echo '<h2>' . __('General Settings') . '</h2>';
     echo '<ul>';
@@ -116,12 +132,10 @@ if ($server > 0 || count($cfg['Servers']) > 1
     /**
      * Displays the MySQL servers choice form
      */
-    if ($cfg['ServerDefault'] == 0 
+    if ($cfg['ServerDefault'] == 0
         || (! $cfg['NavigationDisplayServers']
-            && (count($cfg['Servers']) > 1 
-                || ($server == 0 && count($cfg['Servers']) == 1)
-            )
-        )
+        && (count($cfg['Servers']) > 1
+        || ($server == 0 && count($cfg['Servers']) == 1)))
     ) {
         echo '<li id="li_select_server" class="no_bullets" >';
         include_once 'libraries/select_server.lib.php';
@@ -153,15 +167,12 @@ if ($server > 0 || count($cfg['Servers']) > 1
         } // end if
         echo '    <li id="li_select_mysql_collation" class="no_bullets" >';
         echo '        <form method="post" action="index.php">' . "\n"
-           . PMA_generate_common_hidden_inputs(null, null, 4, 'collation_connection')
+           . PMA_URL_getHiddenInputs(null, null, 4, 'collation_connection')
            . '            <label for="select_collation_connection">' . "\n"
-           . '                '. PMA_Util::getImage('s_asci.png') . " " 
+           . '                '. PMA_Util::getImage('s_asci.png') . " "
                                . __('Server connection collation') . "\n"
            // put the doc link in the form so that it appears on the same line
-           . PMA_Util::showMySQLDocu(
-               'MySQL_Database_Administration',
-               'Charset-connection'
-           )
+           . PMA_Util::showMySQLDocu('Charset-connection')
            . ': ' .  "\n"
            . '            </label>' . "\n"
 
@@ -236,35 +247,39 @@ if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
     echo '<h2>' . __('Database server') . '</h2>';
     echo '<ul>' . "\n";
     PMA_printListItem(
-        __('Server') . ': ' . $server_info,
+        __('Server:') . ' ' . $server_info,
         'li_server_info'
     );
     PMA_printListItem(
-        __('Server type') . ': ' . PMA_Util::getServerType(),
+        __('Server type:') . ' ' . PMA_Util::getServerType(),
         'li_server_type'
     );
     PMA_printListItem(
-        __('Server version') . ': ' . PMA_MYSQL_STR_VERSION . ' - ' . PMA_MYSQL_VERSION_COMMENT,
+        __('Server version:')
+        . ' '
+        . PMA_MYSQL_STR_VERSION . ' - ' . PMA_MYSQL_VERSION_COMMENT,
         'li_server_version'
     );
     PMA_printListItem(
-        __('Protocol version') . ': ' . PMA_DBI_get_proto_info(),
+        __('Protocol version:') . ' ' . $GLOBALS['dbi']->getProtoInfo(),
         'li_mysql_proto'
     );
     PMA_printListItem(
-        __('User') . ': ' . htmlspecialchars($mysql_cur_user_and_host),
+        __('User:') . ' ' . htmlspecialchars($mysql_cur_user_and_host),
         'li_user_info'
     );
 
     echo '    <li id="li_select_mysql_charset">';
-    echo '        ' . __('Server charset') . ': '
-       . '        <span lang="en" dir="ltr">'
-       . '           ' . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']] . "\n"
-       . '           (' . $mysql_charset_map['utf-8'] . ')' . "\n"
-       . '        </span>' . "\n"
-       . '    </li>' . "\n";
-    echo '  </ul>';
-    echo ' </div>';
+    echo '        ' . __('Server charset:') . ' '
+       . '        <span lang="en" dir="ltr">';
+    if (! PMA_DRIZZLE) {
+        echo '           ' . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
+    }
+    echo '           (' . $mysql_charset_map['utf-8'] . ')'
+       . '        </span>'
+       . '    </li>'
+       . '  </ul>'
+       . ' </div>';
 }
 
 if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
@@ -275,18 +290,21 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
         PMA_printListItem($_SERVER['SERVER_SOFTWARE'], 'li_web_server_software');
 
         if ($server > 0) {
-            $client_version_str = PMA_DBI_get_client_info();
+            $client_version_str = $GLOBALS['dbi']->getClientInfo();
             if (preg_match('#\d+\.\d+\.\d+#', $client_version_str)
-                && in_array($GLOBALS['cfg']['Server']['extension'], array('mysql', 'mysqli'))
+                && in_array(
+                    $GLOBALS['cfg']['Server']['extension'],
+                    array('mysql', 'mysqli')
+                )
             ) {
                 $client_version_str = 'libmysql - ' . $client_version_str;
             }
             PMA_printListItem(
-                __('Database client version') . ': ' . $client_version_str,
+                __('Database client version:') . ' ' . $client_version_str,
                 'li_mysql_client_version'
             );
 
-            $php_ext_string = __('PHP extension') . ': '
+            $php_ext_string = __('PHP extension:') . ' '
                 . $GLOBALS['cfg']['Server']['extension'] . ' '
                 . PMA_Util::showPHPDocu(
                     'book.' . $GLOBALS['cfg']['Server']['extension'] . '.php'
@@ -323,7 +341,7 @@ if ($GLOBALS['cfg']['VersionCheck']
     $class = 'jsversioncheck';
 }
 PMA_printListItem(
-    __('Version information') . ': ' . PMA_VERSION,
+    __('Version information:') . ' ' . PMA_VERSION,
     'li_pma_version',
     null,
     null,
@@ -375,15 +393,13 @@ PMA_printListItem(
     null,
     '_blank'
 );
-?>
-    </ul>
- </div>
+echo '    </ul>';
+echo ' </div>';
 
-</div>
+echo '</div>';
 
-</div>
+echo '</div>';
 
-<?php
 /**
  * Warning if using the default MySQL privileged account
  */
@@ -392,29 +408,44 @@ if ($server != 0
     && $cfg['Server']['password'] == ''
 ) {
     trigger_error(
-        __('Your configuration file contains settings (root with no password) that correspond to the default MySQL privileged account. Your MySQL server is running with this default, is open to intrusion, and you really should fix this security hole by setting a password for user \'root\'.'),
+        __(
+            'Your configuration file contains settings (root with no password)'
+            . ' that correspond to the default MySQL privileged account.'
+            . ' Your MySQL server is running with this default, is open to'
+            . ' intrusion, and you really should fix this security hole by'
+            . ' setting a password for user \'root\'.'
+        ),
         E_USER_WARNING
     );
 }
 
 /**
- * Nijel: As we try to handle charsets by ourself, mbstring overloads just
+ * As we try to handle charsets by ourself, mbstring overloads just
  * break it, see bug 1063821.
  */
 if (@extension_loaded('mbstring') && @ini_get('mbstring.func_overload') > 1) {
     trigger_error(
-        __('You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause some data to be corrupted!'),
+        __(
+            'You have enabled mbstring.func_overload in your PHP '
+            . 'configuration. This option is incompatible with phpMyAdmin '
+            . 'and might cause some data to be corrupted!'
+        ),
         E_USER_WARNING
     );
 }
 
 /**
- * Nijel: mbstring is used for handling multibyte inside parser, so it is good
+ * mbstring is used for handling multibyte inside parser, so it is good
  * to tell user something might be broken without it, see bug #1063149.
  */
 if (! @extension_loaded('mbstring')) {
     trigger_error(
-        __('The mbstring PHP extension was not found and you seem to be using a multibyte charset. Without the mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.'),
+        __(
+            'The mbstring PHP extension was not found and you seem to be using'
+            . ' a multibyte charset. Without the mbstring extension phpMyAdmin'
+            . ' is unable to split strings correctly and it may result in'
+            . ' unexpected results.'
+        ),
         E_USER_WARNING
     );
 }
@@ -460,7 +491,7 @@ if (! empty($_SESSION['auto_blowfish_secret'])
  */
 if (file_exists('config')) {
     trigger_error(
-        __('Directory [code]config[/code], which is used by the setup script, still exists in your phpMyAdmin directory. You should remove it once phpMyAdmin has been configured.'),
+        __('Directory [code]config[/code], which is used by the setup script, still exists in your phpMyAdmin directory. It is strongly recommended to remove it once phpMyAdmin has been configured. Otherwise the security of your server may be compromised by unauthorized people downloading your configuration.'),
         E_USER_WARNING
     );
 }
@@ -472,7 +503,8 @@ if ($server > 0) {
     ) {
         $msg = PMA_Message::notice(__('The phpMyAdmin configuration storage is not completely configured, some extended features have been deactivated. To find out why click %shere%s.'));
         $msg->addParam(
-            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?' . $common_url_query . '">',
+            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?'
+            . $common_url_query . '">',
             false
         );
         $msg->addParam('</a>', false);
@@ -489,12 +521,15 @@ if ($server > 0) {
  * (a difference on the third digit does not count).
  * If someday there is a constant that we can check about mysqlnd,
  * we can use it instead of strpos().
- * If no default server is set, PMA_DBI_get_client_info() is not defined yet.
+ * If no default server is set, $GLOBALS['dbi'] is not defined yet.
  * Drizzle can speak MySQL protocol, so don't warn about version mismatch for
  * Drizzle servers.
  */
-if (function_exists('PMA_DBI_get_client_info') && !PMA_DRIZZLE) {
-    $_client_info = PMA_DBI_get_client_info();
+if (isset($GLOBALS['dbi'])
+    && !PMA_DRIZZLE
+    && $cfg['ServerLibraryDifference_DisableWarning'] == false
+) {
+    $_client_info = $GLOBALS['dbi']->getClientInfo();
     if ($server > 0
         && strpos($_client_info, 'mysqlnd') === false
         && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(PMA_MYSQL_INT_VERSION, 0, 3)
@@ -518,11 +553,10 @@ if (function_exists('PMA_DBI_get_client_info') && !PMA_DRIZZLE) {
 }
 
 /**
- * Warning about Suhosin
+ * Warning about Suhosin only if its simulation mode is not enabled
  */
 if ($cfg['SuhosinDisableWarning'] == false
     && @ini_get('suhosin.request.max_value_length')
-    // warn about Suhosin only if its simulation mode is not enabled
     && @ini_get('suhosin.simulation') == '0'
 ) {
     trigger_error(
@@ -560,7 +594,9 @@ if (file_exists('libraries/language_stats.inc.php')) {
         && $GLOBALS['language_stats'][$lang] < $cfg['TranslationWarningThreshold']
     ) {
         trigger_error(
-            'You are using an incomplete translation, please help to make it better by <a href="http://www.phpmyadmin.net/home_page/improve.php#translate" target="_blank">contributing</a>.',
+            'You are using an incomplete translation, please help to make it '
+            . 'better by [a@http://www.phpmyadmin.net/home_page/improve.php'
+            . '#translate@_blank]contributing[/a].',
             E_USER_NOTICE
         );
     }
@@ -581,8 +617,9 @@ if (file_exists('libraries/language_stats.inc.php')) {
  *
  * @return void
  */
-function PMA_printListItem($name, $id = null, $url = null, $mysql_help_page = null,
-    $target = null, $a_id = null, $class = null, $a_class = null
+function PMA_printListItem($name, $id = null, $url = null,
+    $mysql_help_page = null, $target = null, $a_id = null, $class = null,
+    $a_class = null
 ) {
     echo '<li id="' . $id . '"';
     if (null !== $class) {
@@ -609,7 +646,7 @@ function PMA_printListItem($name, $id = null, $url = null, $mysql_help_page = nu
         echo '</a>' . "\n";
     }
     if (null !== $mysql_help_page) {
-        echo PMA_Util::showMySQLDocu('', $mysql_help_page);
+        echo PMA_Util::showMySQLDocu($mysql_help_page);
     }
     echo '</li>';
 }
