@@ -17,8 +17,8 @@
  * // get simple success message 'Success'
  * $message = PMA_Message::success();
  *
- * // get special notice 'Some locale notice'
- * $message = PMA_Message::notice('strSomeLocaleNotice');
+ * // get special notice
+ * $message = PMA_Message::notice(__('This is a localized notice'));
  * </code>
  *
  * more advanced usage example:
@@ -27,15 +27,15 @@
  * $message = PMA_Message::success('strSomeLocaleMessage');
  *
  * // create another message, a hint, with a localized string which expects
- * // two parameters: $strSomeFootnote = 'Read the %smanual%s'
- * $hint = PMA_Message::notice('strSomeFootnote');
- * // replace %d with the following params
- * $hint->addParam('[a@./Documentation.html#cfg_Example@_blank]');
- * $hint->addParam('[/a]');
- * // add this hint as a footnote
- * $hint = PMA_showHint($hint);
+ * // two parameters: $strSomeTooltip = 'Read the %smanual%s'
+ * $hint = PMA_Message::notice('strSomeTooltip');
+ * // replace placeholders with the following params
+ * $hint->addParam('[doc@cfg_Example]');
+ * $hint->addParam('[/doc]');
+ * // add this hint as a tooltip
+ * $hint = showHint($hint);
  *
- * // add the retrieved footnote reference to the original message
+ * // add the retrieved tooltip reference to the original message
  * $message->addMessage($hint);
  *
  * // create another message ...
@@ -54,6 +54,7 @@
  * // strSomeLocaleMessage <sup>1</sup> strSomeMoreLocale<br />
  * // strSomeEvenMoreLocale - some final words
  * </code>
+ *
  * @package PhpMyAdmin
  */
 class PMA_Message
@@ -84,7 +85,7 @@ class PMA_Message
      * @access  protected
      * @var     integer
      */
-    protected $_number = PMA_Message::NOTICE;
+    protected $number = PMA_Message::NOTICE;
 
     /**
      * The locale string identifier
@@ -92,7 +93,7 @@ class PMA_Message
      * @access  protected
      * @var     string
      */
-    protected $_string = '';
+    protected $string = '';
 
     /**
      * The formatted message
@@ -100,7 +101,7 @@ class PMA_Message
      * @access  protected
      * @var     string
      */
-    protected $_message = '';
+    protected $message = '';
 
     /**
      * Whether the message was already displayed
@@ -108,7 +109,7 @@ class PMA_Message
      * @access  protected
      * @var     boolean
      */
-    protected $_is_displayed = false;
+    protected $isDisplayed = false;
 
     /**
      * Unique id
@@ -116,7 +117,7 @@ class PMA_Message
      * @access  protected
      * @var string
      */
-    protected $_hash = null;
+    protected $hash = null;
 
     /**
      * holds parameters
@@ -124,7 +125,7 @@ class PMA_Message
      * @access  protected
      * @var     array
      */
-    protected $_params = array();
+    protected $params = array();
 
     /**
      * holds additional messages
@@ -132,19 +133,20 @@ class PMA_Message
      * @access  protected
      * @var     array
      */
-    protected $_added_messages = array();
+    protected $addedMessages = array();
 
     /**
      * Constructor
      *
-     * @param string  $string
-     * @param integer $number
-     * @param array   $params
-     * @param integer $sanitize
+     * @param string  $string   The message to be displayed
+     * @param integer $number   A numeric representation of the type of message
+     * @param array   $params   An array of parameters to use in the message
+     * @param integer $sanitize A flag to indicate what to sanitize, see
+     *                          constant definitions above
      */
     public function __construct($string = '', $number = PMA_Message::NOTICE,
-        $params = array(), $sanitize = PMA_Message::SANITIZE_NONE)
-    {
+        $params = array(), $sanitize = PMA_Message::SANITIZE_NONE
+    ) {
         $this->setString($string, $sanitize & PMA_Message::SANITIZE_STRING);
         $this->setNumber($number);
         $this->setParams($params, $sanitize & PMA_Message::SANITIZE_PARAMS);
@@ -165,9 +167,12 @@ class PMA_Message
      *
      * shorthand for getting a simple success message
      *
+     * @param string $string A localized string
+     *                       e.g. __('Your SQL query has been
+     *                       executed successfully')
+     *
+     * @return PMA_Message
      * @static
-     * @param string $string a localized string e.g. __('Your SQL query has been executed successfully')
-     * @return  PMA_Message
      */
     static public function success($string = '')
     {
@@ -183,9 +188,10 @@ class PMA_Message
      *
      * shorthand for getting a simple error message
      *
+     * @param string $string A localized string e.g. __('Error')
+     *
+     * @return PMA_Message
      * @static
-     * @param string $string a localized string e.g. __('Error')
-     * @return  PMA_Message
      */
     static public function error($string = '')
     {
@@ -201,9 +207,13 @@ class PMA_Message
      *
      * shorthand for getting a simple notice message
      *
+     * @param string $string A localized string
+     *                       e.g. __('The additional features for working with
+     *                       linked tables have been deactivated. To find out
+     *                       why click %shere%s.')
+     *
+     * @return PMA_Message
      * @static
-     * @param string  $string a localized string e.g. __('The additional features for working with linked tables have been deactivated. To find out why click %shere%s.')
-     * @return  PMA_Message
      */
     static public function notice($string)
     {
@@ -215,10 +225,11 @@ class PMA_Message
      *
      * shorthand for getting a customized message
      *
+     * @param string  $message A localized string
+     * @param integer $type    A numeric representation of the type of message
+     *
+     * @return PMA_Message
      * @static
-     * @param string    $message
-     * @param integer   $type
-     * @return  PMA_Message
      */
     static public function raw($message, $type = PMA_Message::NOTICE)
     {
@@ -232,13 +243,16 @@ class PMA_Message
      *
      * shorthand for getting a customized message
      *
+     * @param integer $rows Number of rows
+     *
+     * @return PMA_Message
      * @static
-     * @param integer   $rows Number of rows
-     * @return  PMA_Message
      */
-    static public function affected_rows($rows)
+    static public function getMessageForAffectedRows($rows)
     {
-        $message = PMA_Message::success(_ngettext('%1$d row affected.', '%1$d rows affected.', $rows));
+        $message = PMA_Message::success(
+            _ngettext('%1$d row affected.', '%1$d rows affected.', $rows)
+        );
         $message->addParam($rows);
         return $message;
     }
@@ -248,13 +262,16 @@ class PMA_Message
      *
      * shorthand for getting a customized message
      *
+     * @param integer $rows Number of rows
+     *
+     * @return PMA_Message
      * @static
-     * @param integer   $rows Number of rows
-     * @return  PMA_Message
      */
-    static public function deleted_rows($rows)
+    static public function getMessageForDeletedRows($rows)
     {
-        $message = PMA_Message::success(_ngettext('%1$d row deleted.', '%1$d rows deleted.', $rows));
+        $message = PMA_Message::success(
+            _ngettext('%1$d row deleted.', '%1$d rows deleted.', $rows)
+        );
         $message->addParam($rows);
         return $message;
     }
@@ -264,13 +281,16 @@ class PMA_Message
      *
      * shorthand for getting a customized message
      *
+     * @param integer $rows Number of rows
+     *
+     * @return PMA_Message
      * @static
-     * @param integer   $rows Number of rows
-     * @return  PMA_Message
      */
-    static public function inserted_rows($rows)
+    static public function getMessageForInsertedRows($rows)
     {
-        $message = PMA_Message::success(_ngettext('%1$d row inserted.', '%1$d rows inserted.', $rows));
+        $message = PMA_Message::success(
+            _ngettext('%1$d row inserted.', '%1$d rows inserted.', $rows)
+        );
         $message->addParam($rows);
         return $message;
     }
@@ -280,9 +300,10 @@ class PMA_Message
      *
      * shorthand for getting a customized error message
      *
+     * @param string $message A localized string
+     *
+     * @return PMA_Message
      * @static
-     * @param string  $message
-     * @return  PMA_Message
      */
     static public function rawError($message)
     {
@@ -294,9 +315,10 @@ class PMA_Message
      *
      * shorthand for getting a customized notice message
      *
+     * @param string $message A localized string
+     *
+     * @return PMA_Message
      * @static
-     * @param string  $message
-     * @return  PMA_Message
      */
     static public function rawNotice($message)
     {
@@ -308,9 +330,10 @@ class PMA_Message
      *
      * shorthand for getting a customized success message
      *
+     * @param string $message A localized string
+     *
+     * @return PMA_Message
      * @static
-     * @param string  $message
-     * @return  PMA_Message
      */
     static public function rawSuccess($message)
     {
@@ -321,8 +344,9 @@ class PMA_Message
      * returns whether this message is a success message or not
      * and optionaly makes this message a success message
      *
-     * @param boolean $set
-     * @return  boolean whether this is a success message or not
+     * @param boolean $set Whether to make this message of SUCCESS type
+     *
+     * @return boolean whether this is a success message or not
      */
     public function isSuccess($set = false)
     {
@@ -337,8 +361,9 @@ class PMA_Message
      * returns whether this message is a notice message or not
      * and optionally makes this message a notice message
      *
-     * @param boolean $set
-     * @return  boolean whether this is a notice message or not
+     * @param boolean $set Whether to make this message of NOTICE type
+     *
+     * @return boolean whether this is a notice message or not
      */
     public function isNotice($set = false)
     {
@@ -353,8 +378,9 @@ class PMA_Message
      * returns whether this message is an error message or not
      * and optionally makes this message an error message
      *
-     * @param boolean $set
-     * @return  boolean whether this is an error message or not
+     * @param boolean $set Whether to make this message of ERROR type
+     *
+     * @return boolean Whether this is an error message or not
      */
     public function isError($set = false)
     {
@@ -368,39 +394,45 @@ class PMA_Message
     /**
      * set raw message (overrides string)
      *
-     * @param string  $message
-     * @param boolean $sanitize whether to sanitize $message or not
+     * @param string  $message  A localized string
+     * @param boolean $sanitize Whether to sanitize $message or not
+     *
+     * @return void
      */
     public function setMessage($message, $sanitize = false)
     {
         if ($sanitize) {
             $message = PMA_Message::sanitize($message);
         }
-        $this->_message = $message;
+        $this->message = $message;
     }
 
     /**
      * set string (does not take effect if raw message is set)
      *
-     * @param string  $_string
+     * @param string  $string   string to set
      * @param boolean $sanitize whether to sanitize $string or not
+     *
+     * @return void
      */
-    public function setString($_string, $sanitize = true)
+    public function setString($string, $sanitize = true)
     {
         if ($sanitize) {
-            $_string = PMA_Message::sanitize($_string);
+            $string = PMA_Message::sanitize($string);
         }
-        $this->_string = $_string;
+        $this->string = $string;
     }
 
     /**
      * set message type number
      *
-     * @param integer $number
+     * @param integer $number message type number to set
+     *
+     * @return void
      */
     public function setNumber($number)
     {
-        $this->_number = $number;
+        $this->number = $number;
     }
 
     /**
@@ -413,37 +445,44 @@ class PMA_Message
      * $message->addParam('<img src="img" />', false);
      * </code>
      *
-     * @param mixed   $param
-     * @param boolean $raw
+     * @param mixed   $param parameter to add
+     * @param boolean $raw   whether parameter should be passed as is
+     *                       without html escaping
+     *
+     * @return void
      */
     public function addParam($param, $raw = true)
     {
         if ($param instanceof PMA_Message) {
-            $this->_params[] = $param;
+            $this->params[] = $param;
         } elseif ($raw) {
-            $this->_params[] = htmlspecialchars($param);
+            $this->params[] = htmlspecialchars($param);
         } else {
-            $this->_params[] = PMA_Message::notice($param);
+            $this->params[] = PMA_Message::notice($param);
         }
     }
 
     /**
      * add another string to be concatenated on displaying
      *
-     * @param string  $string    to be added
-     * @param string  $separator to use between this and previous string/message
+     * @param string $string    to be added
+     * @param string $separator to use between this and previous string/message
+     *
+     * @return void
      */
     public function addString($string, $separator = ' ')
     {
-        $this->_added_messages[] = $separator;
-        $this->_added_messages[] = PMA_Message::notice($string);
+        $this->addedMessages[] = $separator;
+        $this->addedMessages[] = PMA_Message::notice($string);
     }
 
     /**
      * add a bunch of messages at once
      *
-     * @param array   $messages  to be added
-     * @param string  $separator to use between this and previous string/message
+     * @param array  $messages  to be added
+     * @param string $separator to use between this and previous string/message
+     *
+     * @return void
      */
     public function addMessages($messages, $separator = ' ')
     {
@@ -455,34 +494,38 @@ class PMA_Message
     /**
      * add another raw message to be concatenated on displaying
      *
-     * @param mixed   $message   to be added
-     * @param string  $separator to use between this and previous string/message
+     * @param mixed  $message   to be added
+     * @param string $separator to use between this and previous string/message
+     *
+     * @return void
      */
     public function addMessage($message, $separator = ' ')
     {
         if (strlen($separator)) {
-            $this->_added_messages[] = $separator;
+            $this->addedMessages[] = $separator;
         }
 
         if ($message instanceof PMA_Message) {
-            $this->_added_messages[] = $message;
+            $this->addedMessages[] = $message;
         } else {
-            $this->_added_messages[] = PMA_Message::rawNotice($message);
+            $this->addedMessages[] = PMA_Message::rawNotice($message);
         }
     }
 
     /**
      * set all params at once, usually used in conjunction with string
      *
-     * @param array   $params
-     * @param boolean $sanitize
+     * @param array   $params   parameters to set
+     * @param boolean $sanitize whether to sanitize params
+     *
+     * @return void
      */
     public function setParams($params, $sanitize = false)
     {
         if ($sanitize) {
             $params = PMA_Message::sanitize($params);
         }
-        $this->_params = $params;
+        $this->params = $params;
     }
 
     /**
@@ -492,7 +535,7 @@ class PMA_Message
      */
     public function getParams()
     {
-        return $this->_params;
+        return $this->params;
     }
 
     /**
@@ -502,16 +545,17 @@ class PMA_Message
      */
     public function getAddedMessages()
     {
-        return $this->_added_messages;
+        return $this->addedMessages;
     }
 
     /**
      * Sanitizes $message
      *
-     * @static
-     * @param mixed  $message the message(s)
-     * @return  mixed  the sanitized message(s)
+     * @param mixed $message the message(s)
+     *
+     * @return mixed  the sanitized message(s)
      * @access  public
+     * @static
      */
     static public function sanitize($message)
     {
@@ -530,10 +574,11 @@ class PMA_Message
      * decode $message, taking into account our special codes
      * for formatting
      *
-     * @static
-     * @param string  $message the message
-     * @return  string  the decoded message
+     * @param string $message the message
+     *
+     * @return string  the decoded message
      * @access  public
+     * @static
      */
     static public function decodeBB($message)
     {
@@ -543,7 +588,7 @@ class PMA_Message
     /**
      * wrapper for sprintf()
      *
-     * @return  string formatted
+     * @return string formatted
      */
     static public function format()
     {
@@ -557,31 +602,31 @@ class PMA_Message
     }
 
     /**
-     * returns unique PMA_Message::$_hash, if not exists it will be created
+     * returns unique PMA_Message::$hash, if not exists it will be created
      *
-     * @return  string PMA_Message::$_hash
+     * @return string PMA_Message::$hash
      */
     public function getHash()
     {
-        if (null === $this->_hash) {
-            $this->_hash = md5(
+        if (null === $this->hash) {
+            $this->hash = md5(
                 $this->getNumber() .
-                $this->_string .
-                $this->_message
+                $this->string .
+                $this->message
             );
         }
 
-        return $this->_hash;
+        return $this->hash;
     }
 
     /**
      * returns compiled message
      *
-     * @return  string complete message
+     * @return string complete message
      */
     public function getMessage()
     {
-        $message = $this->_message;
+        $message = $this->message;
 
         if (0 === strlen($message)) {
             $string = $this->getString();
@@ -594,6 +639,9 @@ class PMA_Message
             }
         }
 
+        if ($this->isDisplayed()) {
+            $message = $this->getMessageWithIcon($message);
+        }
         if (count($this->getParams()) > 0) {
             $message = PMA_Message::format($message, $this->getParams());
         }
@@ -608,29 +656,29 @@ class PMA_Message
     }
 
     /**
-     * returns PMA_Message::$_string
+     * returns PMA_Message::$string
      *
-     * @return  string PMA_Message::$_string
+     * @return string PMA_Message::$string
      */
     public function getString()
     {
-        return $this->_string;
+        return $this->string;
     }
 
     /**
-     * returns PMA_Message::$_number
+     * returns PMA_Message::$number
      *
-     * @return  integer PMA_Message::$_number
+     * @return integer PMA_Message::$number
      */
     public function getNumber()
     {
-        return $this->_number;
+        return $this->number;
     }
 
     /**
      * returns level of message
      *
-     * @return  string  level of message
+     * @return string  level of message
      */
     public function getLevel()
     {
@@ -640,6 +688,7 @@ class PMA_Message
     /**
      * Displays the message in HTML
      *
+     * @return void
      */
     public function display()
     {
@@ -650,11 +699,11 @@ class PMA_Message
     /**
      * returns HTML code for displaying this message
      *
-     *
      * @return string whole message box
      */
     public function getDisplay()
     {
+        $this->isDisplayed(true);
         return '<div class="' . $this->getLevel() . '">'
             . $this->getMessage() . '</div>';
     }
@@ -662,16 +711,39 @@ class PMA_Message
     /**
      * sets and returns whether the message was displayed or not
      *
-     * @param boolean $is_displayed
-     * @return  boolean PMA_Message::$_is_displayed
+     * @param boolean $isDisplayed whether to set displayed flag
+     *
+     * @return boolean PMA_Message::$isDisplayed
      */
-    public function isDisplayed($is_displayed = false)
+    public function isDisplayed($isDisplayed = false)
     {
-        if ($is_displayed) {
-            $this->_is_displayed = true;
+        if ($isDisplayed) {
+            $this->isDisplayed = true;
         }
 
-        return $this->_is_displayed;
+        return $this->isDisplayed;
+    }
+
+    /**
+     * Returns the message with corresponding image icon
+     *
+     * @param string $message the message(s)
+     *
+     * @return string message with icon
+     */
+    public function getMessageWithIcon($message)
+    {
+        $image = '';
+        if ('error' == $this->getLevel()) {
+            $image = 's_error.png';
+        } elseif ('success' == $this->getLevel()) {
+            $image = 's_success.png';
+        } else {
+            $image = 's_notice.png';
+        }
+        $message = PMA_Message::notice(PMA_Util::getImage($image)) . " " . $message;
+        return $message;
+
     }
 }
 ?>
