@@ -11,7 +11,7 @@ if (! defined('PHPMYADMIN')) {
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_bdb extends PMA_StorageEngine
+class PMA_StorageEngine_Bdb extends PMA_StorageEngine
 {
     /**
      * Returns array with variable names related to this storage engine
