@@ -17,7 +17,7 @@ require_once './libraries/engines/bdb.lib.php';
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_berkeleydb extends PMA_StorageEngine_bdb
+class PMA_StorageEngine_berkeleydb extends PMA_StorageEngine_Bdb
 {
 }
 
