@@ -3,6 +3,9 @@
 /**
  * @package PhpMyAdmin-Engines
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  *
@@ -12,9 +15,9 @@ class PMA_StorageEngine_binlog extends PMA_StorageEngine
 {
     /**
      * returns string with filename for the MySQL helppage
-     * about this storage engne
+     * about this storage engine
      *
-     * @return  string  mysql helppage filename
+     * @return string  mysql helppage filename
      */
     function getMysqlHelpPage()
     {
