@@ -9,12 +9,14 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/navigation/Nodes/Node_DatabaseChild.class.php';
+
 /**
  * Represents a view node in the navigation tree
  *
  * @package PhpMyAdmin-Navigation
  */
-class Node_View extends Node
+class Node_View extends Node_DatabaseChild
 {
     /**
      * Initialises the class
@@ -29,7 +31,7 @@ class Node_View extends Node
     public function __construct($name, $type = Node::OBJECT, $is_group = false)
     {
         parent::__construct($name, $type, $is_group);
-        $this->icon  = PMA_Util::getImage('b_views.png');
+        $this->icon  = PMA_Util::getImage('b_props.png', __('View'));
         $this->links = array(
             'text' => 'sql.php?server=' . $GLOBALS['server']
                     . '&amp;db=%2$s&amp;table=%1$s&amp;pos=0'
@@ -38,6 +40,17 @@ class Node_View extends Node
                     . '&amp;db=%2$s&amp;table=%1$s'
                     . '&amp;token=' . $GLOBALS['token']
         );
+        $this->classes = 'view';
+    }
+
+    /**
+     * Returns the type of the item represented by the node.
+     *
+     * @return string type of the item
+     */
+    protected function getItemType()
+    {
+        return 'view';
     }
 }
 
