@@ -1,3 +1,4 @@
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Functions used in Setup configuration forms
  */
@@ -14,17 +15,17 @@ if (top != self) {
 // stores hidden message ids
 var hiddenMessages = [];
 
-$(function() {
+$(function () {
     var hidden = hiddenMessages.length;
     for (var i = 0; i < hidden; i++) {
-        $('#'+hiddenMessages[i]).css('display', 'none');
+        $('#' + hiddenMessages[i]).css('display', 'none');
     }
     if (hidden > 0) {
         var link = $('#show_hidden_messages');
-        link.click(function(e) {
+        link.click(function (e) {
             e.preventDefault();
             for (var i = 0; i < hidden; i++) {
-                $('#'+hiddenMessages[i]).show(500);
+                $('#' + hiddenMessages[i]).show(500);
             }
             $(this).remove();
         });
@@ -41,6 +42,70 @@ $(function() {
 // Form validation and field operations
 //
 
+/**
+ * Calls server-side validation procedures
+ *
+ * @param {Element} parent  input field in <fieldset> or <fieldset>
+ * @param {String}  id      validator id
+ * @param {Object}  values  values hash {element1_id: value, ...}
+ */
+function ajaxValidate(parent, id, values)
+{
+    parent = $(parent);
+    // ensure that parent is a fieldset
+    if (parent.attr('tagName') != 'FIELDSET') {
+        parent = parent.closest('fieldset');
+        if (parent.length === 0) {
+            return false;
+        }
+    }
+
+    if (parent.data('ajax') !== null) {
+        parent.data('ajax').abort();
+    }
+
+    parent.data('ajax', $.ajax({
+        url: 'validate.php',
+        cache: false,
+        type: 'POST',
+        data: {
+            token: parent.closest('form').find('input[name=token]').val(),
+            id: id,
+            values: $.toJSON(values)
+        },
+        success: function (response) {
+            if (response === null) {
+                return;
+            }
+
+            var error = {};
+            if (typeof response != 'object') {
+                error[parent.id] = [response];
+            } else if (typeof response.error != 'undefined') {
+                error[parent.id] = [response.error];
+            } else {
+                for (var key in response) {
+                    var value = response[key];
+                    error[key] = jQuery.isArray(value) ? value : [value];
+                }
+            }
+            displayErrors(error);
+        },
+        complete: function () {
+            parent.removeData('ajax');
+        }
+    }));
+
+    return true;
+}
+
+/**
+ * Automatic form submission on change.
+ */
+$('.autosubmit').live('change', function (e) {
+    e.target.form.submit();
+});
+
 $.extend(true, validators, {
     // field validators
     _field: {
@@ -49,8 +114,8 @@ $.extend(true, validators, {
          *
          * @param {boolean} isKeyUp
          */
-        hide_db: function(isKeyUp) {
-            if (!isKeyUp && this.value != '') {
+        hide_db: function (isKeyUp) {
+            if (!isKeyUp && this.value !== '') {
                 var data = {};
                 data[this.id] = this.value;
                 ajaxValidate(this, 'Servers/1/hide_db', data);
@@ -62,8 +127,8 @@ $.extend(true, validators, {
          *
          * @param {boolean} isKeyUp
          */
-        TrustedProxies: function(isKeyUp) {
-            if (!isKeyUp && this.value != '') {
+        TrustedProxies: function (isKeyUp) {
+            if (!isKeyUp && this.value !== '') {
                 var data = {};
                 data[this.id] = this.value;
                 ajaxValidate(this, 'TrustedProxies', data);
@@ -78,7 +143,7 @@ $.extend(true, validators, {
          *
          * @param {boolean} isKeyUp
          */
-        Server: function(isKeyUp) {
+        Server: function (isKeyUp) {
             if (!isKeyUp) {
                 ajaxValidate(this, 'Server', getAllValues());
             }
@@ -89,7 +154,7 @@ $.extend(true, validators, {
          *
          * @param {boolean} isKeyUp
          */
-        Server_login_options: function(isKeyUp) {
+        Server_login_options: function (isKeyUp) {
             return validators._fieldset.Server.apply(this, [isKeyUp]);
         },
         /**
@@ -97,14 +162,13 @@ $.extend(true, validators, {
          *
          * @param {boolean} isKeyUp
          */
-        Server_pmadb: function(isKeyUp) {
+        Server_pmadb: function (isKeyUp) {
             if (isKeyUp) {
                 return true;
             }
 
             var prefix = getIdPrefix($(this).find('input'));
-            var pmadb_active = $('#' + prefix + 'pmadb').val() != '';
-            if (pmadb_active) {
+            if ($('#' + prefix + 'pmadb').val() !== '') {
                 ajaxValidate(this, 'Server_pmadb', getAllValues());
             }
 
@@ -113,63 +177,6 @@ $.extend(true, validators, {
     }
 });
 
-/**
- * Calls server-side validation procedures
- *
- * @param {Element} parent  input field in <fieldset> or <fieldset>
- * @param {String}  id      validator id
- * @param {Object}  values  values hash {element1_id: value, ...}
- */
-function ajaxValidate(parent, id, values)
-{
-    parent = $(parent);
-    // ensure that parent is a fieldset
-    if (parent.attr('tagName') != 'FIELDSET') {
-        parent = parent.closest('fieldset');
-        if (parent.length == 0) {
-            return false;
-        }
-    }
-
-    if (parent.data('ajax') != null) {
-        parent.data('ajax').abort();
-    }
-
-    parent.data('ajax', $.ajax({
-        url: 'validate.php',
-        cache: false,
-        type: 'POST',
-        data: {
-            token: parent.closest('form').find('input[name=token]').val(),
-            id: id,
-            values: $.toJSON(values)
-        },
-        success: function(response) {
-            if (response == null) {
-                return;
-            }
-
-            var error = {};
-            if (typeof response != 'object') {
-                error[parent.id] = [response];
-            } else if (typeof response['error'] != 'undefined') {
-                error[parent.id] = [response['error']];
-            } else {
-                for (var key in response) {
-                    var value = response[key];
-                    error[key] = jQuery.isArray(value) ? value : [value];
-                }
-            }
-            displayErrors(error);
-        },
-        complete: function() {
-            parent.removeData('ajax');
-        }
-    }));
-
-    return true;
-}
-
 //
 // END: Form validation and field operations
 // ------------------------------------------------------------------
@@ -178,17 +185,17 @@ function ajaxValidate(parent, id, values)
 // User preferences allow/disallow UI
 //
 
-$(function() {
-   $('.userprefs-allow').click(function(e) {
-       if (this != e.target) {
-           return;
-       }
-       var el = $(this).find('input');
-       if (el.attr('disabled')) {
-           return;
-       }
-       el.attr('checked', !el.attr('checked'));
-   });
+$(function () {
+    $('.userprefs-allow').click(function (e) {
+        if (this != e.target) {
+            return;
+        }
+        var el = $(this).find('input');
+        if (el.prop('disabled')) {
+            return;
+        }
+        el.prop('checked', !el.prop('checked'));
+    });
 });
 
 //
